@@ -2,7 +2,7 @@
 #' @description Extracts data from the Energy Information Administration (EIA) API to tibble format with optional custom series name.
 #' Makes a clean wrapper for use with purrr for multiple series extraction. Query Browser at https://www.eia.gov/opendata/qb.php.
 #' @param ticker EIA series name.
-#' @param key Your private EIA API token as character "<yourapikey>".
+#' @param key Your private EIA API token as character "yourapikey".
 #' @param name Name you want to give the series. Defaults to ticker if set to " "
 #' @return A tibble object with class date for weekly, monthly, quarterly or annual data and class POSIXct for hourly.
 #' @export eia2tidy
@@ -26,7 +26,7 @@ eia2tidy <- function(ticker, key, name = " ") {
   if (nchar(name) == 1) {
     name <- ticker
   }
-  url <- paste0("http://api.eia.gov/series/?api_key=", key, "&series_id=", ticker, "&out=json")
+  url <- paste0("https://api.eia.gov/series/?api_key=", key, "&series_id=", ticker, "&out=json")
   x <- url %>% httr::GET()
   x <- jsonlite::fromJSON(httr::content(x, "text", encoding = "UTF-8"))
   # promises::promise(~print(x$data$error)) %>%
